pub enum YamlValue {
String(String),
Integer(i64),
Float(f64),
Boolean(bool),
Null,
Array(YamlArray),
Object(YamlObject),
}Expand description
YAML value representation.
This represents the pure value of a YAML element without any source code location information.
Variants
String(String)
String value.
Integer(i64)
Integer value.
Float(f64)
Floating-point value.
Boolean(bool)
Boolean value.
Null
Null value.
Array(YamlArray)
Array value.
Object(YamlObject)
Object value.
Implementations
Sourceimpl YamlValue
impl YamlValue
Sourcepub fn as_integer(&self) -> Option<i64>
pub fn as_integer(&self) -> Option<i64>
Returns the integer value if the value is an integer.
Sourcepub fn as_float(&self) -> Option<f64>
pub fn as_float(&self) -> Option<f64>
Returns the floating-point value if the value is a float.
Sourcepub fn as_array(&self) -> Option<&Vec<YamlValue>>
pub fn as_array(&self) -> Option<&Vec<YamlValue>>
Returns a reference to the array if the value is an array.